# UserResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**first_name** | **str** |  | [optional] 
**last_name** | **str** |  | [optional] 
**organisation_name** | **str** |  | 
**roles** | [**list[RoleResponse]**](RoleResponse.md) |  | [optional] 
**roles_string** | **list[str]** |  | [optional] 
**organisation_reference** | **str** |  | 
**contracts** | [**list[OrganisationSummaryResponse]**](OrganisationSummaryResponse.md) |  | [optional] 
**workstreams** | [**list[UserWorkstreamAccessDetails]**](UserWorkstreamAccessDetails.md) |  | [optional] 
**organisation_status** | **AllOfUserResponseOrganisationStatus** |  | [optional] 
**organisation_status_string** | **str** |  | [optional] 
**role_permissions** | [**list[RolePermissionsResponse]**](RolePermissionsResponse.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

